@@ -14,7 +14,7 @@ import java.util.List;
 import java.util.Vector;
 
 import org.gnu.glib.GObject;
-import org.gnu.glib.Handle;
+import org.gnu.javagnome.Handle;
 
 /**
  * ConfClient provides a client-side cache for a specified list of directories
@@ -481,6 +481,6 @@ public class ConfClient extends GObject {
 
 
 	static {
-		System.loadLibrary("gconfjni-2.10");
+		System.loadLibrary("gconfjni-2.11");
 	}
 }
